@@ -1073,12 +1073,12 @@ std::string PostScript_Support::ConvertToDate(const char* inString)
 			{
 				if ( date.containsOffset )
 				{
-					sprintf(dtstr,"%04d-%02d-%02dT%02d:%02d:%02d%c%02d:%02d",date.year,date.month,date.day,
+					snprintf(dtstr,sizeof(dtstr),"%04d-%02d-%02dT%02d:%02d:%02d%c%02d:%02d",date.year,date.month,date.day,
 							date.hours,date.minutes,date.seconds,date.offsetSign,date.offsetHour,date.offsetMin);
 				}
 				else
 				{
-					sprintf(dtstr,"%04d-%02d-%02dT%02d:%02d:%02dZ",date.year,date.month,date.day,
+					snprintf(dtstr,sizeof(dtstr),"%04d-%02d-%02dT%02d:%02d:%02dZ",date.year,date.month,date.day,
 							date.hours,date.minutes,date.seconds);
 				}
 				try
